# ProtobufStruct

`Struct` represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, `Struct` might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.  The JSON representation for `Struct` is JSON object.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**fields** | [**dict(str, ProtobufValue)**](ProtobufValue.md) | Unordered map of dynamically typed values. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


